/**
 * @file
 * Front-end Administration handling of blocks.
 *
 * Sponsored by: www.freelance-drupal.com
 */

(function ($, Drupal) {

    // Should work for most cases
    var _uniqId = function() {
        return Math.round(new Date().getTime() + (Math.random() * 100));
    }

    /**
     * Start the block handling behavior:
     *  - move block around, from one region to another.
     */
    Drupal.behaviors.feadmin_block = {
        attach: function(context, settings) {

            // Regions are sortable: blocks can move around.
            $("[data-region]").sortable({
                connectWith: "[data-region]",
                items: "[data-block]",
                placeholder: "block-placeholder ui-state-highlight",

                // Display the region indicators.
                start: function( event, ui ) {
                    // Remove all sidebars body configurations and add two sidebars.
                    $('body').removeClass(function (index, css) {
                        return (css.match (/(^|\s)layout-\S+/g) || []).join(' ');
                    }).addClass('layout-two-sidebars');
                    // Show empty blocks and regions.
                    $(".empty-region, .empty-block").show();
                },

                // Hide the region indicators.
                stop: function( event, ui ) {
                    // Remove all sidebars configurations on body.
                    $('body').removeClass(function (index, css) {
                        return (css.match (/(^|\s)layout-\S+/g) || []).join(' ');
                    });
                    // Count number of sidebar columns now filled.
                    var sidebarsCount, sidebars = $('[data-region*="sidebar"]:not(".empty-region")');
                    if (sidebars.length) {
                        sidebarsCount = (sidebars.length == 1) ? 'one' : 'two';
                    } else {
                        sidebarsCount = 'no';
                    }
                    // Add body general sidebar configurations.
                    $('body').addClass('layout-' + sidebarsCount + '-sidebar' + ((sidebars.length == 2) ? 's' : ''));
                    // Add specific sidebars
                    if (sidebars.length == 1) {
                        // Find the sidebar name.
                        $('body').addClass('layout-' + sidebars.data('region').replace('_', '-'));
                    }

                    // Hide empty blocks and regions.
                    $(".empty-region, .empty-block").hide();
                },

                // Display some blocks placeholder indicators.
                sort: function( event, ui ) {
                    $(".block-placeholder").text(Drupal.t("Drop your block here"));
                },

                // Update the block orders after the dragging was completed.
                update: function( event, ui ) {
                    if (this === ui.item.parent()[0]) {

                        // The destination region cannot be empty anymore.
                        $(this).removeClass('empty-region');

                        // The origin region may now be empty.
                        if (ui.sender && $("[data-block]:not('.empty-block')", ui.sender).length == 0) {
                            ui.sender.addClass('empty-region');
                        }

                        var destinationRegionName = $(this).data('region');
                        var originRegionName = ui.sender ? ui.sender.data('region') : destinationRegionName;
                        var request = {};

                        // Build destination region
                        request['region'] = destinationRegionName;
                        request['blocks'] = new Array();
                        $("[data-block]", $(this)).each(function() {
                            request['blocks'].push($(this).data('block'));
                        });

                        // Send the changed data to our backend.
                        var uniqId = _uniqId();
                        $.ajax({
                            type: "POST",
                            url: Drupal.url('feadmin/callback/blocks'),
                            contentType: "application/json",
                            data: JSON.stringify(request),
                            beforeSend: function( xhr ) {
                                notif = $.notify(Drupal.t("Blocks position are saving..."), {
                                    className: ['wait', uniqId],
                                    position: 'right bottom'
                                });
                            },
                            success: function(data) {
                                $(".notifyjs-bootstrap-" + uniqId).trigger('notify-hide');
                                $.notify(data, {
                                    className: 'success',
                                    position: 'right bottom'
                                });
                            },
                            error: function(data) {
                                $(".notifyjs-bootstrap-" + uniqId).trigger('notify-hide');
                                $.notify(Drupal.t("An error has happened: blocks positionning is not saved."), {
                                    className: 'error',
                                    position: 'right bottom'
                                });
                            },

                        });

                    }
                }
            });
        }
    };
})(jQuery, Drupal);