/**
 * @file
 * Front-end Administration handling of menus.
 *
 * Sponsored by: www.freelance-drupal.com
 */

(function ($, Drupal) {

    // Should work for most cases
    var _uniqId = function() {
        return Math.round(new Date().getTime() + (Math.random() * 100));
    }

    /**
     * Start the menu handling behavior:
     *  - move menu item around, within it's menu.
     */
    Drupal.behaviors.feadmin_menu = {
        attach: function(context, settings) {

            // Regions are sortable: blocks can move around.
            $("[data-menu]").sortable({
                items: "[data-menu-item]",
                placeholder: "menu-placeholder ui-state-highlight",

                // Display some menu item placeholder indicators.
                sort: function( event, ui ) {
                    $(".menu-placeholder").text(Drupal.t("Drop here"));
                },

                // Update the menu orders after the dragging was completed.
                update: function( event, ui ) {
                    if (this === ui.item.parent()[0]) {

                        var destinationMenuName = $(this).data('menu');
                        var request = {};

                        // Build destination region
                        request['menu'] = destinationMenuName;
                        request['menu_items'] = new Array();
                        $("[data-menu-item]", $(this)).each(function() {
                            request['menu_items'].push($(this).data('menu-item'));
                        });

                        // Send the changed data to our backend.
                        var uniqId = _uniqId();
                        $.ajax({
                            type: "POST",
                            url: Drupal.url('feadmin/callback/menus'),
                            contentType: "application/json",
                            data: JSON.stringify(request),
                            beforeSend: function( xhr ) {
                                notif = $.notify(Drupal.t("Menu items are saving..."), {
                                    className: ['wait', uniqId],
                                    position: 'right bottom'
                                });
                            },
                            success: function(data) {
                                $(".notifyjs-bootstrap-" + uniqId).trigger('notify-hide');
                                $.notify(data, {
                                    className: 'success',
                                    position: 'right bottom'
                                });
                            },
                            error: function(data) {
                                $(".notifyjs-bootstrap-" + uniqId).trigger('notify-hide');
                                $.notify(Drupal.t("An error has happened: menu items order is not saved."), {
                                    className: 'error',
                                    position: 'right bottom'
                                });
                            },

                        });

                    }
                }
            });
        }
    };
})(jQuery, Drupal);