<?php

/**
 * @file
 * Contains \Drupal\system\Form\SiteInformationForm.
 */

namespace Drupal\feadmin\Form;

use Drupal\Core\Cache\Cache;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Path\AliasManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Path\PathValidatorInterface;
use Drupal\Core\Routing\RequestContext;
use Drupal\Core\Theme\ThemeManagerInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure site information settings for this site.
 */
class FeAdminSettingsForm extends ConfigFormBase {

  /**
   * The theme manager.
   *
   * @var \Drupal\Core\Theme\ThemeManagerInterface
   */
  protected $theme_manager;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'feadmin_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['feadmin.settings'];
  }

  /**
   * Constructs a SiteInformationForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Theme\ThemeManagerInterface $theme_manager
   *   The theme manager
   */
  public function __construct(ConfigFactoryInterface $config_factory, ThemeManagerInterface $theme_manager) {
    parent::__construct($config_factory);
    $this->theme_manager = $theme_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('theme.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $feadmin_settings = $this->config('feadmin.settings');

    $form['admin_blocks'] = array(
      '#type' => 'checkbox',
      '#title' => t('Drag & Drop blocks on front.'),
      '#description' => t('This option let\'s you drag&drop blocks from one region to another on front directly. This operation is equivalent to what can be done on @admin_block_page, thus, users must have <i>administer blocks</i> permission to use this feature.', array('@admin_block_page' => Link::createFromRoute(t('admin block page'), 'block.admin_display')->toString())),
      '#default_value' => $feadmin_settings->get('admin_blocks'),
    );

    $form['admin_menus'] = array(
      '#type' => 'checkbox',
      '#title' => t('Drag & Drop menu items on front.'),
      '#description' => t('This option let\'s you reorder menu items inside it\'s menu. This operation is equivalent to what can be done on @admin_menu_page, thus, users must have <i>administer blocks</i> permission to use this feature.', array('@admin_menu_page' => Link::createFromRoute(t('admin menu page'), 'entity.menu.collection')->toString())),
      '#default_value' => $feadmin_settings->get('admin_menus'),
    );
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('feadmin.settings')
      ->set('admin_blocks', $form_state->getValue('admin_blocks'))
      ->set('admin_menus', $form_state->getValue('admin_menus'))
      ->save();

    Cache::invalidateTags(['rendered']);

    parent::submitForm($form, $form_state);
  }

}
